@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::CheckBreaks;
-# git description: v0.010-2-g9825135
-$Dist::Zilla::Plugin::Test::CheckBreaks::VERSION = '0.011';
+package Dist::Zilla::Plugin::Test::CheckBreaks; # git description: v0.011-10-ga86c7a7
 # ABSTRACT: Generate a test that shows what modules you are breaking
 # KEYWORDS: distribution prerequisites upstream dependencies modules conflicts breaks breakages metadata
-# vim: set ts=8 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+
+our $VERSION = '0.012';
 
 use Moose;
 with (
@@ -13,8 +13,8 @@ with (
     'Dist::Zilla::Role::FileMunger',
     'Dist::Zilla::Role::TextTemplate',
     'Dist::Zilla::Role::PrereqSource',
+    'Dist::Zilla::Role::ModuleMetadata',
 );
-use Module::Metadata 1.000005;
 use Path::Tiny;
 use Module::Runtime 'module_notional_filename';
 use List::Util 1.33 qw(any first);
@@ -56,15 +56,8 @@ has conflicts_module => (
         my $self = shift;
 
         $self->log_debug('no conflicts_module provided; looking for one in the dist...');
-        # TODO: use Dist::Zilla::Role::ModuleMetadata
-        my $main_file = $self->zilla->main_module;
-        my $fh;
-        ($main_file->can('encoding')
-            ? open $fh, sprintf('<encoding(%s)', $main_file->encoding), \$main_file->encoded_content
-            : open $fh, '<', \$main_file->content)
-                or $self->log_fatal('cannot open handle to ' . $main_file->name . ' content: ' . $!);
 
-        my $mmd = Module::Metadata->new_from_handle($fh, $main_file->name);
+        my $mmd = $self->module_metadata_for_file($self->zilla->main_module);
         my $module = ($mmd->packages_inside)[0] . '::Conflicts';
 
         # check that the file exists in the dist (it should never be shipped
@@ -72,11 +65,11 @@ has conflicts_module => (
         my $conflicts_filename = module_notional_filename($module);
         if (any { $_->name eq path('lib', $conflicts_filename) } @{ $self->zilla->files })
         {
-            $self->log_debug($module . ' found');
+            $self->log_debug([ '%s found', $module ]);
             return $module;
         }
 
-        $self->log_debug('No ' . $module . ' found');
+        $self->log_debug([ 'No %s found', $module ]);
         return undef;
     },
 );
@@ -218,7 +211,7 @@ Dist::Zilla::Plugin::Test::CheckBreaks - Generate a test that shows what modules
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -333,7 +326,7 @@ ___[ test-check-breaks ]___
 use strict;
 use warnings;
 
-# this test was generated with {{ ref($plugin) . ' ' . ($plugin->VERSION || '<self>') }}
+# this test was generated with {{ ref($plugin) . ' ' . $plugin->VERSION }}
 
 use Test::More 0.88;
 
